@@ -3100,7 +3100,7 @@ cmp_keyvalue_value_i(const void *a, const void *b)
     return STRICMP(kv1->value, kv2->value);
 }
 
-// compare two keyvalue_T structs by case insensitive value
+// compare two keyvalue_T structs by case insensitive ASCII value
 // with length
     int
 cmp_keyvalue_value_ni(const void *a, const void *b)
@@ -3108,6 +3108,6 @@ cmp_keyvalue_value_ni(const void *a, const void *b)
     keyvalue_T *kv1 = (keyvalue_T *)a;
     keyvalue_T *kv2 = (keyvalue_T *)b;
 
-    return STRNICMP(kv1->value, kv2->value, MAX(kv1->length, kv2->length));
+    return vim_strnicmp_asc(kv1->value, kv2->value, MAX(kv1->length, kv2->length));
 }
 
